@@ -1,8 +1,8 @@
 from enum import Enum
 from typing import Optional
-from .common import GraphBase, NodeItem
+from .common import GraphBase, NodeItem, ExportItem, ExportBase
 import numpy as np
-
+import pandas as pd
 
 class DelayType(Enum):
     """
@@ -26,6 +26,18 @@ class DelayTarget(Enum):
     DelayMS = 1  # 按毫秒统计的延迟
     DelayUS = 2  # 按微秒统计的延迟
 
+    @staticmethod
+    def getUnit(delayTargetName: str) -> str:
+        value = DelayTarget[delayTargetName].value
+        if value == 0:
+            return "Second"
+        elif value == 1:
+            return "Millisecond"
+        elif value == 3:
+            return "Microsecond"
+        else:
+            return "unknown"
+
 
 class DelayItem:
     """
@@ -234,14 +246,8 @@ class Delay:
         return delay
 
 
-class DelayGraph(GraphBase):
-    """
-    一个用于实现绘制延迟图的类
-    """
-
-    def __init__(self, delay: Delay):
-        super().__init__()
-        self.delay = delay
+class DelayExtractBase:
+    def __init__(self):
         self.samplingInterval = 1.0
         self.delayType = DelayType.LastDelay
         self.delayTarget = DelayTarget.DelayMS
@@ -273,6 +279,46 @@ class DelayGraph(GraphBase):
         self.delayTarget = delayTarget
         return self
 
+
+class DelayExport(DelayExtractBase, ExportBase):
+    """
+    一个用于将延迟统计结果导出到Excel的辅助类
+    """
+    def __init__(self, delay: Delay):
+        def getNode(nodeName):
+            return self.delay.getByNode(nodeName)
+
+        def getX(node: NodeDelay, nodeId):
+            return node.getX(nodeId, samplingInterval=self.samplingInterval)
+
+        def getY(node: NodeDelay, nodeId):
+            return node.getY(nodeId, self.delayType, self.delayTarget, self.samplingInterval)
+
+        def getUnit():
+            return DelayTarget.getUnit(self.delayTarget.name)
+        ExportBase.__init__(self, getNode, getX, getY, getUnit)
+        DelayExtractBase.__init__(self)
+        self.delay = delay
+
+    def exportExcel(self, savePath: str):
+        self.innerExportExcel(savePath, "Times", "Second")
+        return self
+
+    @staticmethod
+    def parse(inputFile: str):
+        return DelayExport(Delay.parse(inputFile))
+
+
+class DelayGraph(GraphBase, DelayExtractBase):
+    """
+    一个用于实现绘制延迟图的类
+    """
+
+    def __init__(self, delay: Delay):
+        GraphBase.__init__(self)
+        DelayExtractBase.__init__(self)
+        self.delay = delay
+
     def plot(self, node: str, appId: int, *args,
              color: str = "&&",
              linewidth: float = 2, linestyle: str = "dotted", marker: str = "&&",
