@@ -137,13 +137,6 @@ class DeliveryTimeGraph(GraphBase):
         self.ax.title(label, fontdict=fontdict, loc=loc, pad=pad, **kwargs)
         return self
 
-    def xlabel(self, xlabel, fontdict=None, labelpad=None, loc=None, **kwargs):
-        self.ax.xlabel(xlabel, fontdict, labelpad, loc=loc, **kwargs)
-        return self
-
-    def ylabel(self, ylabel, fontdict=None, labelpad=None, loc=None, **kwargs):
-        self.ax.ylabel(ylabel, fontdict, labelpad, loc=loc, **kwargs)
-        return self
 
     def legend(self, *args, **kwargs):
         handles, labels = self.ax.get_legend_handles_labels()
@@ -175,10 +168,10 @@ class DeliveryTimeGraph(GraphBase):
         x = np.arange(maxSize)
         total_width, n = self.totalWidth, maxN
         width = total_width / n
-        x = x - (total_width - width) / 2
+        x = x - ((len(self.deliveryTimeCollections) - 1) * width / 2)
 
         self.fig, self.ax = plt.subplots(figsize=self.figSize)
-        offsetX, isFirst = width / 2, True
+        offsetX, isFirst =  0, True
         for dtc in self.deliveryTimeCollections:
             bottom = np.zeros(len(dtc.contentDeliveryTimeGroups[0]))
             for i in range(len(dtc.colors)):
