@@ -329,6 +329,10 @@ class DropGraph(GraphBase):
                           **kwargs)
         return self
 
+    def innerParse(self, inputFile: str):
+        self.drop = Drop.parse(inputFile)
+        return self
+
     @staticmethod
     def parse(inputFile: str):
         return DropGraph(Drop.parse(inputFile))
