@@ -1,6 +1,8 @@
 from enum import Enum
 from typing import Optional
-from .common import GraphBase, NodeItem
+from .common import GraphBase, NodeItem, ExportItem, ExportBase
+import numpy as np
+import pandas as pd
 
 
 class ThroughputType(Enum):
@@ -47,6 +49,22 @@ class ThroughputTarget(Enum):
     KilobytesRaw_Kbps = 8
     KilobytesRaw_Mbps = 9
 
+    @staticmethod
+    def getUnit(throughputTargetName: str) -> str:
+        value = ThroughputTarget[throughputTargetName].value
+        if value == 0 or value == 5:
+            return "Number of packets"
+        elif value == 1 or value == 6:
+            return "KBps"
+        elif value == 2 or value == 7:
+            return "MBps"
+        elif value == 3 or value == 8:
+            return "Kbps"
+        elif value == 4 or value == 9:
+            return "Mbps"
+        else:
+            return "unknown"
+
 
 class ThroughputItem:
     """
@@ -77,34 +95,37 @@ class ThroughputItem:
         self.KilobytesRaw = KilobytesRaw
 
     def getValueByThroughputTarget(self, throughputTarget: ThroughputTarget, lpPacketHeaderSize: int = 0):
-        self.Kilobytes += ((self.Packets * lpPacketHeaderSize) / 1000)
-        self.KilobytesRaw += ((self.PacketRaw * lpPacketHeaderSize) / 1000)
+        kilobytes, kilobytesRaw = self.Kilobytes, self.KilobytesRaw
+        if kilobytes > 0:
+            kilobytes += ((self.Packets * lpPacketHeaderSize) / 1000)
+        if kilobytesRaw > 0:
+            kilobytesRaw += ((self.PacketRaw * lpPacketHeaderSize) / 1000)
         if throughputTarget == ThroughputTarget.Packets:
             return self.Packets
         elif throughputTarget == ThroughputTarget.Kilobytes_KBps:
-            return self.Kilobytes
+            return kilobytes
         elif throughputTarget == ThroughputTarget.Kilobytes_MBps:
-            return self.Kilobytes / 1000
+            return kilobytes / 1000
         elif throughputTarget == ThroughputTarget.Kilobytes_Kbps:
-            return self.Kilobytes * 8
+            return kilobytes * 8
         elif throughputTarget == ThroughputTarget.Kilobytes_Mbps:
-            return self.Kilobytes * 8 / 1000
+            return kilobytes * 8 / 1000
         elif throughputTarget == ThroughputTarget.PacketRaw:
             return self.PacketRaw
         elif throughputTarget == ThroughputTarget.KilobytesRaw_KBps:
-            return self.KilobytesRaw
+            return kilobytesRaw
         elif throughputTarget == ThroughputTarget.KilobytesRaw_MBps:
-            return self.KilobytesRaw / 1000
+            return kilobytesRaw / 1000
         elif throughputTarget == ThroughputTarget.KilobytesRaw_Kbps:
-            return self.KilobytesRaw * 8
+            return kilobytesRaw * 8
         elif throughputTarget == ThroughputTarget.KilobytesRaw_Mbps:
-            return self.KilobytesRaw * 8 / 1000
+            return kilobytesRaw * 8 / 1000
 
     @staticmethod
     def parseLine(line: str):
         # 0.5	C1	1	internal://	InInterests	0	0	0	0
         values = line.strip().split("\t")
-        if len(values) < 9:
+        if len(values) != 9:
             return None
         return ThroughputItem(float(values[0].strip()),
                               values[1].strip(),
@@ -283,14 +304,8 @@ class Throughput:
         return throughput
 
 
-class ThroughputGraph(GraphBase):
-    """
-    一个用于实现绘制吞吐量图的类
-    """
-
-    def __init__(self, throughput: Throughput):
-        super().__init__()
-        self.throughput = throughput
+class ThroughputExtractBase:
+    def __init__(self):
         self.samplingInterval = 1.0
         self.throughputType = ThroughputType.OutData
         self.throughputTarget = ThroughputTarget.Kilobytes_KBps
@@ -332,6 +347,52 @@ class ThroughputGraph(GraphBase):
         self.lpPacketHeaderSize = lpPacketHeaderSize
         return self
 
+
+class ThroughputExport(ThroughputExtractBase, ExportBase):
+    """
+    一个用于导出数据到Excel的辅助类
+    """
+
+    def __init__(self, throughput: Throughput):
+        def getNode(nodeName):
+            return self.throughput.getByNode(nodeName)
+
+        def getX(node: NodeThroughput, nodeId):
+            return node.getX(nodeId, samplingInterval=self.samplingInterval)
+
+        def getY(node: NodeThroughput, nodeId):
+            return node.getY(nodeId, self.throughputType, self.throughputTarget, self.samplingInterval,
+                             self.lpPacketHeaderSize)
+        def getUnit():
+            return ThroughputTarget.getUnit(self.throughputTarget.name)
+
+        ThroughputExtractBase.__init__(self)
+        ExportBase.__init__(self, getNode, getX, getY, getUnit)
+        self.throughput = throughput
+
+    def exportExcel(self, savePath: str):
+        self.innerExportExcel(savePath)
+        return self
+
+    def innerParse(self, inputFile: str):
+        self.throughput = Throughput.parse(inputFile)
+        return self
+
+    @staticmethod
+    def parse(inputFile: str):
+        return ThroughputExport(Throughput.parse(inputFile))
+
+
+class ThroughputGraph(GraphBase, ThroughputExtractBase):
+    """
+    一个用于实现绘制吞吐量图的类
+    """
+
+    def __init__(self, throughput: Throughput):
+        GraphBase.__init__(self)
+        ThroughputExtractBase.__init__(self)
+        self.throughput = throughput
+
     def plot(self, node: str, faceId: int, *args,
              color: str = "&&",
              linewidth: float = 2, linestyle: str = "dotted", marker: str = "&&",
@@ -407,6 +468,10 @@ class ThroughputGraph(GraphBase):
                           **kwargs)
         return self
 
+    def innerParse(self, inputFile: str):
+        self.throughput = Throughput.parse(inputFile)
+        return self
+
     @staticmethod
     def parse(inputFile: str):
         return ThroughputGraph(Throughput.parse(inputFile))
